@@ -27,12 +27,12 @@ class MetisRemoteExporter(SpanExporter):
     def export(self, spans: Sequence[ReadableSpan]) -> SpanExportResult:
         try:
 
-            data = [span.to_json(indent=0) for span in spans if METIS_STATEMENT_SPAN_ATTRIBUTE in span.attributes or
+            data = [span.to_json(indent=None) for span in spans if METIS_STATEMENT_SPAN_ATTRIBUTE in span.attributes or
                     METIS_REQUEST_SPAN_ATTRIBUTE_IDENTIFIER in span.attributes]
             if data:
                 result = self.session.post(
                     url=self.url,
-                        json=data
+                    json=data
                 )
                 logger.debug(result.text)
 
