@@ -20,10 +20,9 @@ from sqlalchemycollector.exporters.file_exporter import MetisFileExporter
 from sqlalchemycollector.exporters.remote_exporter import MetisRemoteExporter
 from sqlalchemycollector.plan_collect_type import PlanCollectType
 from sqlalchemycollector.utils.env_var import extract_additional_tags_from_env_var
-from sqlalchemycollector.utils.log import log, logger, log_summary
+from sqlalchemycollector.utils.log import log, logger
 from sqlalchemycollector.utils.once import Once
 from sqlalchemycollector.utils.singleton_class import SingletonMeta
-from sqlalchemycollector.version import __version__
 
 METIS_INSTRUMENTATION_STR = "METIS_INSTRUMENTATION"
 
@@ -250,6 +249,3 @@ class MetisInstrumentor(metaclass=SingletonMeta):
         if self.sqlalchemy_instrumentor is not None:
             self.sqlalchemy_instrumentor.uninstrument()
 
-    def __del__(self):
-        log_summary()
-
